@@ -2,7 +2,7 @@
 
    Copyright (C) 2001 Stephen L. Moshier <moshier@na-net.ornl.gov>
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2001, 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2001-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -164,7 +164,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
   flag = 0;
   sign = (x < 0.0DL)?1:0;
 
-  ix = FUNC_D(fabs) (x);
+  ix = FUNC_D(__fabs) (x);
 
   if (ix >= 1.0DL)	/* |x|>= 1 */
     {
