@@ -41,6 +41,15 @@
    __hidden_proto (__dpd_##name, __GI___dpd_##name, ##attrs)
 #endif
 
+/* Older versions of GCC support __int128 differently.  */
+#ifdef HAVE_UINT128_T
+# define UINT128 __uint128_t
+# define INT128 __int128_t
+#elif HAVE_INT128
+# define INT128 __int128
+# define UINT128 unsigned __int128
+#endif
+
 /* This file contains the prototypes for the DFP arithmetic, conversion, and
  * comparison routines.  These also exist in libgcc, but these versions
  * support decimal floating point rounding control and exception support
@@ -64,11 +73,15 @@ hidden_proto_enc (divdd3)
 _Decimal128 __BACKEND_(divtd3) (_Decimal128,_Decimal128);
 hidden_proto_enc (divtd3)
 
-int __BACKEND_(eqsd2) (_Decimal32,_Decimal32);
+/* The result of a comparison is a bit more complicated
+   than an int type.  */
+typedef int CMPINT __attribute__ ((mode (__libgcc_cmp_return__)));
+
+CMPINT __BACKEND_(eqsd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (eqsd2)
-int __BACKEND_(eqdd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(eqdd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (eqdd2)
-int __BACKEND_(eqtd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(eqtd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (eqtd2)
 
 _Decimal64  __BACKEND_(extendsddd2) (_Decimal32);
@@ -127,6 +140,22 @@ hidden_proto_enc (fixunsdddi)
 unsigned long long __BACKEND_(fixunstddi) (_Decimal128);
 hidden_proto_enc (fixunstddi)
 
+#if defined(HAVE_UINT128_T) || defined(HAVE_INT128)
+UINT128 __BACKEND_(fixunssdti) (_Decimal32);
+hidden_proto_enc (fixunssdti)
+UINT128 __BACKEND_(fixunsddti) (_Decimal64);
+hidden_proto_enc (fixunsddti)
+UINT128 __BACKEND_(fixunstdti) (_Decimal128);
+hidden_proto_enc (fixunstdti)
+
+INT128 __BACKEND_(fixsdti) (_Decimal32);
+hidden_proto_enc (fixsdti)
+INT128 __BACKEND_(fixddti) (_Decimal64);
+hidden_proto_enc (fixddti)
+INT128 __BACKEND_(fixtdti) (_Decimal128);
+hidden_proto_enc (fixtdti)
+#endif
+
 _Decimal64 __BACKEND_(floatdidd) (long long);
 hidden_proto_enc (floatdidd)
 _Decimal32 __BACKEND_(floatdisd) (long long);
@@ -155,32 +184,48 @@ hidden_proto_enc (floatunssisd)
 _Decimal128 __BACKEND_(floatunssitd) (unsigned int);
 hidden_proto_enc (floatunssitd)
 
-int __BACKEND_(gesd2) (_Decimal32,_Decimal32);
+#if defined(HAVE_UINT128_T) || defined(HAVE_INT128)
+_Decimal32 __BACKEND_(floatunstisd) (UINT128);
+hidden_proto_enc (floatunstisd)
+_Decimal64 __BACKEND_(floatunstidd) (UINT128);
+hidden_proto_enc (floatunstidd)
+_Decimal128 __BACKEND_(floatunstitd) (UINT128);
+hidden_proto_enc (floatunstitd)
+
+_Decimal32 __BACKEND_(floattisd) (INT128);
+hidden_proto_enc (floattisd)
+_Decimal64 __BACKEND_(floattidd) (INT128);
+hidden_proto_enc (floattidd)
+_Decimal128 __BACKEND_(floattitd) (INT128);
+hidden_proto_enc (floattitd)
+#endif
+
+CMPINT __BACKEND_(gesd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (gesd2)
-int __BACKEND_(gedd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(gedd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (gedd2)
-int __BACKEND_(getd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(getd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (getd2)
 
-int __BACKEND_(gtsd2) (_Decimal32,_Decimal32);
+CMPINT __BACKEND_(gtsd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (gtsd2)
-int __BACKEND_(gtdd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(gtdd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (gtdd2)
-int __BACKEND_(gttd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(gttd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (gttd2)
 
-int __BACKEND_(lesd2) (_Decimal32,_Decimal32);
+CMPINT __BACKEND_(lesd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (lesd2)
-int __BACKEND_(ledd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(ledd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (ledd2)
-int __BACKEND_(letd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(letd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (letd2)
 
-int __BACKEND_(ltsd2) (_Decimal32,_Decimal32);
+CMPINT __BACKEND_(ltsd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (ltsd2)
-int __BACKEND_(ltdd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(ltdd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (ltdd2)
-int __BACKEND_(lttd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(lttd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (lttd2)
 
 _Decimal32  __BACKEND_(mulsd3) (_Decimal32,_Decimal32);
@@ -190,11 +235,11 @@ hidden_proto_enc (muldd3)
 _Decimal128 __BACKEND_(multd3) (_Decimal128,_Decimal128);
 hidden_proto_enc (multd3)
 
-int __BACKEND_(nesd2) (_Decimal32,_Decimal32);
+CMPINT __BACKEND_(nesd2) (_Decimal32,_Decimal32);
 hidden_proto_enc (nesd2)
-int __BACKEND_(nedd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(nedd2) (_Decimal64,_Decimal64);
 hidden_proto_enc (nedd2)
-int __BACKEND_(netd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(netd2) (_Decimal128,_Decimal128);
 hidden_proto_enc (netd2)
 
 _Decimal32  __BACKEND_(subsd3) (_Decimal32,_Decimal32);
@@ -232,7 +277,7 @@ hidden_proto_enc (trunctddf)
 long double __BACKEND_(trunctdtf) (_Decimal128);
 hidden_proto_enc (trunctdtf)
 
-int __BACKEND_(unordsd2) (_Decimal32,_Decimal32);
-int __BACKEND_(unorddd2) (_Decimal64,_Decimal64);
-int __BACKEND_(unordtd2) (_Decimal128,_Decimal128);
+CMPINT __BACKEND_(unordsd2) (_Decimal32,_Decimal32);
+CMPINT __BACKEND_(unorddd2) (_Decimal64,_Decimal64);
+CMPINT __BACKEND_(unordtd2) (_Decimal128,_Decimal128);
 #endif /* _DFPACC_PRIVATE_H  */
