@@ -1,6 +1,6 @@
 /* Function definition to convert DFP values to strings
 
-   Copyright (C) 2006-2012 Free Software Foundation, Inc.
+   Copyright (C) 2006-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -354,7 +354,7 @@ __printf_dfp (FILE *fp,
   /* Locale-dependent representation of decimal point.  */
   const char *decimal;
 
-  union { const char *mb; unsigned int wc; } decimalwc;
+  union { const char *mb; int wc; } decimalwc;
 
   char spec = tolower(info->spec);
 
